@@ -3,16 +3,9 @@ if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/doc/HTML/en/kuser ; rm -rf common )
-( cd usr/doc/HTML/en/kuser ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/doc/HTML/en/kcron ; rm -rf common )
 ( cd usr/doc/HTML/en/kcron ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/doc/HTML/en/system-config-printer-kde ; rm -rf common )
-( cd usr/doc/HTML/en/system-config-printer-kde ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/doc/HTML/en/ksystemlog ; rm -rf common )
 ( cd usr/doc/HTML/en/ksystemlog ; ln -sf /usr/share/doc/HTML/en/common common )
-
-if [ -x /usr/bin/update-desktop-database ]; then
-  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
-fi
-
+( cd usr/doc/HTML/en/kuser ; rm -rf common )
+( cd usr/doc/HTML/en/kuser ; ln -sf /usr/share/doc/HTML/en/common common )
